--[[
Name: BagLib-1.0
Revision: $Rev: 45913 $
Author(s): Grennon (jeramy.smith@gmail.com)
Description: A library that provides some basic bag slot operations.
Dependencies: AceLibrary
]]--

local MAJOR_VERSION = "BagLib-1.0"
local MINOR_VERSION = "$Revision: 45913 $"

if not AceLibrary then error(MAJOR_VERSION .. " requires AceLibrary.") end
if not AceLibrary:IsNewVersion(MAJOR_VERSION, MINOR_VERSION) then return end

local lib = {}

-- based on fubar_bagfu
-- returns the number of free slots
function lib:GetNumFreeSlots()
	local totalSlots = 0
	local takenSlots = 0
	for bag = 0, 4 do
		local size = GetContainerNumSlots(bag)
		if size ~= nil and size > 0 then
			totalSlots = totalSlots + size
			for slot = 1, size do
				if GetContainerItemInfo(bag, slot) then takenSlots = takenSlots + 1 end
			end
		end
	end
	return totalSlots - takenSlots
end

--[[
this function returns true if you have a free inventory slot
used a quick check for free space
]]
function lib:GetFreeSlot()
	for bag = 0, 4 do
		local size = GetContainerNumSlots(bag)
		if size ~= nil and size > 0 then
			for slot = 1, size do
				if not GetContainerItemInfo(bag, slot) then return true end
			end
		end
	end
end

function lib:GetSlotTable()
	local invindex = {}
	for bag = 0, 4 do
		local size = GetContainerNumSlots(bag)
		if size ~= nil and size > 0 then
			invindex[bag] = {}
			for slot = 1, size do
				if GetContainerItemInfo(bag, slot) then invindex[bag][slot] = true end
			end
		end
	end
	return invindex
end

function lib:FindTakenSlot(invindex)
	for bag = 0, 4 do
		local size = GetContainerNumSlots(bag)
		if type(size) == "number" and size > 0 then
			for slot = 1, size do
				if GetContainerItemInfo(bag, slot) and not invindex[bag][slot] then
					return bag, slot
				end
			end
		end
	end
end

AceLibrary:Register(lib, MAJOR_VERSION, MINOR_VERSION)
lib = nil

